## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Build -python subpackage
%bcond_without python

#
Name:           rmol
Version:        1.00.14
Release:        %autorelease

Summary:        C++ library of Revenue Management and Optimisation classes and functions

License:        LGPL-2.1-or-later
URL:            https://github.com/airsim/%{name}
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  pkgconfig(readline)
BuildRequires:  soci-devel
BuildRequires:  soci-mysql-devel
BuildRequires:  soci-sqlite3-devel
BuildRequires:  pkgconfig(stdair)
BuildRequires:  pkgconfig(airrac)
BuildRequires:  mysql-devel

%description
%{name} is a C++ library of Revenue Management and Optimisation classes 
and functions. Typically, that library may be used by service providers
(e.g., airlines offering flight seats, hotels offering rooms, rental car
companies offering rental days, broadcasting company offering advertisement 
slots, theaters offering seats, etc.) to help in optimizing their revenues
from seat capacities.
Most of the algorithms implemented are public and documented in the
following book:
The Theory and practice of Revenue Management, by Kalyan T. Talluri and
Garrett J. van Ryzin, Kluwer Academic Publishers, 2004, ISBN 1-4020-7701-7

%{name} makes an extensive use of existing open-source libraries for
increased functionality, speed and accuracy. In particular the
Boost (C++ Standard Extensions: https://www.boost.org) library is used.

Install the %{name} package if you need a library of basic C++ objects
for Airline Revenue Management (RM), mainly for simulation purpose.

%package        devel
Summary:        Header files, libraries and development helper tools for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       pkgconfig

%description    devel
This package contains the header files, shared libraries and
development helper tools for %{name}. If you would like to develop
programs using %{name}, you will need to install %{name}-devel.

%package        doc
Summary:        HTML documentation for the %{name} library
BuildArch:      noarch
BuildRequires:  tex(latex)
BuildRequires:  texlive-epstopdf
BuildRequires:  doxygen
BuildRequires:  ghostscript

%description    doc
This package contains HTML pages, as well as a PDF reference manual,
for %{name}. All that documentation is generated thanks to Doxygen
(https://doxygen.org). The content is the same as what can be browsed
online (https://%{name}.net).

%if %{with python}
%package        -n python3-%{name}
Summary:        Python bindings for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  boost-python3-devel
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package contains Python libraries for %{name}
%endif


%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install

# Removed the Doxygen installer
rm -f %{buildroot}%{_docdir}/%{name}/html/installdox

# Remove additional documentation files (those files are already available
# in the project top directory)
rm -f %{buildroot}%{_docdir}/%{name}/{NEWS,README.md,AUTHORS}

%check
%ctest

%if %{with python}
%post -n python3-%{name}
ln -s -f %{python3_sitearch}/py%{name}/py%{name} %{_bindir}/py%{name}

%postun -n python3-%{name}
rm -f %{_bindir}/py%{name}
%endif


%files
%doc AUTHORS ChangeLog NEWS README.md
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}_drawBPC
%{_bindir}/%{name}_extractBPC
%{_libdir}/lib%{name}.so.*
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/%{name}_drawBPC.1.*
%{_mandir}/man1/%{name}_extractBPC.1.*

%files devel
%license COPYING
%{_includedir}/%{name}/
%{_bindir}/%{name}-config
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_libdir}/cmake/%{name}
%{_libdir}/cmake/%{name}/%{name}-config-version.cmake
%{_libdir}/cmake/%{name}/%{name}-config.cmake
%{_libdir}/cmake/%{name}/%{name}-library-depends.cmake
%{_libdir}/cmake/%{name}/%{name}-library-depends-debug.cmake
%{_datadir}/aclocal/%{name}.m4
%{_mandir}/man1/%{name}-config.1.*
%{_mandir}/man3/%{name}-library.3.*

%files doc
%doc %{_docdir}/%{name}/
%license COPYING

%if %{with python}
%files -n python3-%{name}
%{python3_sitearch}/py%{name}/
%{_mandir}/man1/py%{name}.1.*
%{_libdir}/cmake/%{name}/%{name}-config-python.cmake
%{_libdir}/cmake/%{name}/%{name}-python-library-depends-debug.cmake
%{_libdir}/cmake/%{name}/%{name}-python-library-depends.cmake
%endif

%changelog
## START: Generated by rpmautospec
* Sun Mar 30 2025 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.14-1
- Upstream upgrade

* Tue Mar 25 2025 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.13-1
- Upstream upgrade

* Mon Jan 27 2025 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.12-1
- Upstream update

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.10-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Nov 22 2024 Karolina Surma <ksurma@redhat.com> - 1.00.10-4
- Add Python 3.14 to cmake config

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sat Jun 08 2024 Python Maint <python-maint@redhat.com> - 1.00.10-2
- Rebuilt for Python 3.13

* Sat Mar 23 2024 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.10-1
- Upstream upgrade

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.9-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.9-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Thu Jan 18 2024 Jonathan Wakely <jwakely@redhat.com> - 1.00.9-7
- Rebuilt for Boost 1.83

* Wed Nov 29 2023 Karolina Surma <ksurma@redhat.com> - 1.00.9-6
- Add Python 3.13 to cmake config

* Tue Nov 14 2023 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.9-5
- Modernized the spec file

* Tue Nov 14 2023 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.9-4
- Modernized the spec file

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jun 13 2023 Python Maint <python-maint@redhat.com> - 1.00.9-2
- Rebuilt for Python 3.12

* Mon May 01 2023 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.9-1
- Upstream upgrade

* Mon Feb 20 2023 Jonathan Wakely <jwakely@redhat.com> - 1.00.8-4
- Rebuilt for Boost 1.81

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sun Jul 10 2022 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.8-1
- Upgraded to v1.00.8

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 1.00.7-7
- Rebuilt for Python 3.11

* Wed May 04 2022 Thomas Rodgers <trodgers@redhat.com> - 1.00.7-6
- Rebuilt for Boost 1.78

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Aug 07 2021 Jonathan Wakely <jwakely@redhat.com> - 1.00.7-4
- Rebuilt for Boost 1.76

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sat Jun 26 2021 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.7-2
- [Sources] Support for Python 3.10

* Sat Jun 26 2021 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.7-1
- Upstream update

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 1.00.6-9
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.6-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 22 2021 Jonathan Wakely <jwakely@redhat.com> - 1.00.6-7
- Rebuilt for Boost 1.75

* Sun Aug 09 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.6-6
- Removed the docdir work around (no longer needed)

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.6-5
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jun 06 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.6-3
- Rebuilt for SOCI 4.0.1-alpha2

* Wed Jun 03 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.6-2
- Rebuilt for Boost 1.73

* Sun May 31 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.6-1
- Upstream update

* Sun May 31 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.5-1
- Upstream update

* Tue May 26 2020 Miro Hrončok <miro@hroncok.cz> - 1.00.4-5
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Nov 05 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.4-3
- Upstream update

* Mon Nov 04 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.4-2
- [Changelog] Fixed the date typo

* Mon Nov 04 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.4-1
- Upstream update

* Thu Oct 03 2019 Miro Hrončok <miro@hroncok.cz> - 1.00.3-5
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <miro@hroncok.cz> - 1.00.3-4
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Jul 12 2019 Miro Hrončok <miro@hroncok.cz> - 1.00.3-2
- Pin the Python version this was built with

* Thu Jul 11 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.3-1
- Fixed the release number

* Thu Jul 11 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.1-1
- CMake support files updated for Python 3.8

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jan 24 2019 Jonathan Wakely <jwakely@redhat.com> - 1.00.2-4
- Rebuilt for Boost 1.69

* Thu Jan 17 2019 Miro Hrončok <miro@hroncok.cz> - 1.00.2-3
- No need to exclude libs that are not called lib...so

* Thu Jan 17 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.2-2
- Added the delivery of pyrmol

* Wed Jan 16 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.2-1
- Upstream update

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.1-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Jason Tibbitts <tibbs@math.uh.edu> - 1.00.1-21
- Remove needless use of %%defattr

* Mon Jul 09 2018 Igor Gnatenko <ignatenko@redhat.com> - 1.00.1-20
- add BuildRequires: gcc-c++

* Thu May 10 2018 Jonathan Wakely <jwakely@redhat.com> - 1.00.1-19
- Add BuildRequires: boost-python2-devel to fix build with
  boost-1.66.0-7.fc29

* Wed Feb 14 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.00.1-18
- Remove %%clean section

* Tue Feb 13 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.00.1-17
- Remove BuildRoot definition

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.1-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 23 2018 Jonathan Wakely <jwakely@redhat.com> - 1.00.1-15
- Rebuilt for Boost 1.66

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.1-14
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.1-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 24 2017 Björn Esser <besser82@fedoraproject.org> - 1.00.1-12
- Rebuilt for Boost 1.64

* Mon May 15 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.1-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 12 2017 Igor Gnatenko <ignatenko@redhat.com> - 1.00.1-9
- Rebuild for readline 7.x

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.00.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jan 18 2016 Jonathan Wakely <jwakely@redhat.com> - 1.00.1-7
- Rebuilt for Boost 1.60

* Sun Aug 30 2015 Jonathan Wakely <jwakely@redhat.com> - 1.00.1-6
- Patched and rebuilt for Boost 1.59

* Sat Aug 29 2015 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.1-5
- Mass rebuild

* Wed Jul 29 2015 Dennis Gilmore <dennis@ausil.us> - 1.00.1-4
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 1.00.1-3
- rebuild for Boost 1.58

* Thu Jun 18 2015 Dennis Gilmore <dennis@ausil.us> - 1.00.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Jun 14 2015 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.1-1
- Removed the dependency on ZeroMQ (only AirInv is dependent on it, not
  StdAir)

* Sun May 03 2015 Kalev Lember <kalevlember@gmail.com> - 1.00.0-14
- Rebuilt for GCC 5 C++11 ABI change

* Thu Jan 29 2015 Petr Machata <pmachata@redhat.com> - 1.00.0-13
- Cmake should look for zmq.h, not zmq.hpp

* Thu Jan 29 2015 Petr Machata <pmachata@redhat.com> - 1.00.0-12
- Rebuild for boost 1.57.0

* Mon Aug 18 2014 Peter Robinson <pbrobinson@fedoraproject.org> - 1.00.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 14 2014 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.0-10
- Rebuild for ARM architecture.

* Sat Jun 14 2014 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Jun 08 2014 Dennis Gilmore <dennis@ausil.us> - 1.00.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 1.00.0-7
- rebuild for boost 1.55.0

* Sun Aug 04 2013 Dennis Gilmore <dennis@ausil.us> - 1.00.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 1.00.0-5
- Rebuild for boost 1.54.0

* Mon Jul 29 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.0-4
- Fixed the docdir issue, following the F20 System Wide Change
- Rebuild for Boost-1.54.0

* Wed May 22 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.0-3
- Upstream update

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.0-2
- Rebuild for Boost-1.53.0

* Tue Dec 25 2012 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.00.0-1
- Upstream update

* Sun Aug 12 2012 Kevin Fenzi <kevin@scrye.com> - 0.25.3-5
- Rebuild for new boost

* Sat Jul 21 2012 Dennis Gilmore <dennis@ausil.us> - 0.25.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Dennis Gilmore <dennis@ausil.us> - 0.25.3-3
- Rebuilt for c++ ABI breakage

* Sat Jan 14 2012 Dennis Gilmore <dennis@ausil.us> - 0.25.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Dec 05 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.3-1
- Upstream integration

* Sun Nov 20 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.2-2
- Rebuild for the new Boost-1.48.0

* Wed Nov 02 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.2-1
- Upstream integration

* Wed Oct 26 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.0-6
- clog

* Sun Oct 23 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.0-5
- [Dev] Removed the handling of i18n (.po) files, as it is no longer
  supported.

* Sun Oct 23 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.0-4
- [Build] Added missing dependencies for the build (MySQL).

* Sun Oct 23 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.0-3
- [Dev] Removed the generation of the info files (as they have been
  deprecated for a while.

* Sun Oct 23 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.0-2
- [Sources] New rmol-0.25.0 version.

* Sun Oct 23 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.25.0-1
- Upstream integration

* Sat Jul 23 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.23.1-5
- Rebuild for Boost-1.47.0-2

* Mon Apr 25 2011 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.23.1-4
- Rebuild for Boost-1.46.1-2

* Wed Feb 09 2011 Dennis Gilmore <dennis@ausil.us> - 0.23.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Feb 06 2011 Thomas Spura <tomspur@fedoraproject.org> - 0.23.1-2
- rebuild for new boost

* Tue Sep 07 2010 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.23.1-1
- Upstream integration - Fixed bug #631080
  (https://bugzilla.redhat.com/show_bug.cgi?id=631080)

* Fri Jul 30 2010 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.23.0-8
- Just ignored a few generated files.

* Fri Jul 30 2010 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.23.0-7
- * Wed Jul 28 2010 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.23.0-3 -
  Added a patch to fix Rawhide build error

* Fri Jul 30 2010 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.23.0-6
- Just ignored a few generated files.

* Fri Jul 30 2010 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.23.0-5
- * Wed Jul 28 2010 Denis Arnaud <denis.arnaud_fedora@m4x.org> 0.23.0-3 -
  Added a patch to fix Rawhide build error

* Thu Jul 29 2010 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.23.0-4
- dist-git conversion

* Thu Jan 21 2010 Rahul Sundaram <sundaram@fedoraproject.org> - 0.23.0-3
- Rebuild for Boost soname bump

* Wed Nov 25 2009 Bill Nottingham <notting@fedoraproject.org> - 0.23.0-2
- Fix typo that causes a failure to update the common directory. (releng
  #2781)

* Sat Sep 26 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.23.0-1
- Upstream integration

* Mon Jul 27 2009 Jesse Keating <jkeating@fedoraproject.org> - 0.22.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Jun 06 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.22.0-1
- Upstream integration

* Sun May 10 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.21.0-1
- Removed dependencies on specific versions (for EL 5)

* Mon May 04 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.20.0-4
- Added dependency on libicu for Boost 1.37 (Fedora 11)

* Mon May 04 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.20.0-3
- Added dependency on libicu-devel for Boost 1.37 (Fedora 11)

* Mon May 04 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.20.0-2
- Upstream integration

* Mon May 04 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.20.0-1
- Synchronisation with upstream (new version 0.20.0).

* Tue Apr 14 2009 Denis Arnaud <denisarnaud@fedoraproject.org> - 0.19.0-1
- RPM release for Fedora 10 Wed Mar 4 2009 Denis Arnaud
  <denis.arnaud_fedora@m4x.org> 0.18.0-1 - Second RPM release
## END: Generated by rpmautospec
